@@ -11,6 +11,7 @@ from collections import deque
 from .config import *
 from .tools import *
 from .db import *
+from .dictionary import *
 from . import __version__
 
 
@@ -90,7 +91,7 @@ class DictionaryWindow(QMainWindow):
         self.bar = QStatusBar()
         self.setStatusBar(self.bar)
         self.stats_label = QLabel()
-    
+
         self.sentence.setReadOnly(not (self.settings.value("allow_editing", True, type=bool)))
         self.definition.setReadOnly(not (self.settings.value("allow_editing", True, type=bool)))
 
@@ -155,9 +156,9 @@ class DictionaryWindow(QMainWindow):
         selected = cursor.selectedText().lower()
         cursor2 = self.definition.textCursor()
         selected2 = cursor2.selectedText().lower()
-        target = str.strip(selected or selected2 
-                                    or self.previousWord 
-                                    or self.word.text() 
+        target = str.strip(selected or selected2
+                                    or self.previousWord
+                                    or self.word.text()
                                     or "")
         self.previousWord = target
 
@@ -181,16 +182,16 @@ class DictionaryWindow(QMainWindow):
 
     def getState(self):
         return {'word': self.word.text(), 'definition': self.definition.toPlainText().replace("\n", "<br>")}
-    
+
     def undo(self):
         try:
             self.setState(self.prev_states.pop())
         except IndexError:
             self.setState({'word': "", 'definition': ""})
-    
+
     def setSentence(self, content):
         self.sentence.setText(str.strip(content))
-    
+
     def setWord(self, content):
         self.word.setText(content)
 
@@ -220,29 +221,29 @@ class DictionaryWindow(QMainWindow):
             self.setState(result)
         else:
             self.setSentence(text)
-            
+
     def lookup(self, word, use_lemmatize=True):
         """
-        Look up a word and return a dict with the lemmatized form (if enabled) 
+        Look up a word and return a dict with the lemmatized form (if enabled)
         and definition
         """
         TL = self.settings.value("target_language", "English")
         self.prev_states.append(self.getState())
         lemmatize = use_lemmatize and self.settings.value("lemmatization", True, type=bool)
         short_sign = "Y" if lemmatize else "N"
-        language_code = code[self.settings.value("target_language", "English")]
-        self.status(f"L: '{word}' in '{language_code}', lemma: {short_sign}")
+        language = code[self.settings.value("target_language", "English")]
+        dictname = self.settings.value("dict_source", "Wiktionary (English)")
+        self.status(f"L: '{word}' in '{language}', lemma: {short_sign}, from {dictionaries[dictname]}")
         try:
-            item = wiktionary(removeAccents(word), language_code, lemmatize)
-            item['definition'] = fmt_result(item['definition'])
-            self.rec.recordLookup(word, item['definition'], TL, lemmatize, 'wikt-en', True)
+            item = lookupin(word, language, lemmatize, dictname)
+            self.rec.recordLookup(word, item['definition'], TL, lemmatize, dictionaries[dictname], True)
         except Exception as e:
-            self.status("Lookup failed.")
-            self.rec.recordLookup(word, None, TL, lemmatize, 'wikt-en', False)
+            self.status(str(e))
+            self.rec.recordLookup(word, None, TL, lemmatize, dictionaries[dictname], False)
             self.updateAnkiButtonState(True)
             item = {
-                "word": word, 
-                "definition": failed_lookup(word, self.settings.value("target_language", "English"))
+                "word": word,
+                "definition": failed_lookup(word, self.settings)
                 }
         return item
 
@@ -262,7 +263,6 @@ class DictionaryWindow(QMainWindow):
             "tags": tags
         }
         self.status("Adding note")
-        print(str(content))
         api = self.settings.value("anki_api")
         try:
             addNote(api, content)
@@ -276,7 +276,7 @@ class DictionaryWindow(QMainWindow):
             self.status(f"Failed to add note: {word}")
             self.errorNoConnection(e)
             return
-        
+
     def errorNoConnection(self, error):
         """
         Dialog window sent when something goes wrong in configuration step
@@ -316,11 +316,10 @@ class MyTextEdit(QTextEdit):
         GlobalObject().dispatchEvent("double clicked")
         print("Event sent")
         self.textCursor().clearSelection()
-    
+
 def main():
     app = QApplication(sys.argv)
     w = DictionaryWindow()
-    
+
     w.show()
     sys.exit(app.exec())
-
